from setuptools import setup

name = "types-commonmark"
description = "Typing stubs for commonmark"
long_description = '''
## Typing stubs for commonmark

This is a PEP 561 type stub package for the `commonmark` package.
It can be used by type-checking tools like mypy, PyCharm, pytype etc. to check code
that uses `commonmark`. The source for this package can be found at
https://github.com/python/typeshed/tree/master/stubs/commonmark. All fixes for
types and metadata should be contributed there.

See https://github.com/python/typeshed/blob/master/README.md for more details.
This package was generated from typeshed commit `032e6ee90cbb938259a2aa2183966502de19108e`.
'''.lstrip()

setup(name=name,
      version="0.9.2",
      description=description,
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/python/typeshed",
      install_requires=[],
      packages=['commonmark-stubs'],
      package_data={'commonmark-stubs': ['__init__.pyi', 'blocks.pyi', 'cmark.pyi', 'common.pyi', 'dump.pyi', 'entitytrans.pyi', 'inlines.pyi', 'main.pyi', 'node.pyi', 'normalize_reference.pyi', 'render/__init__.pyi', 'render/html.pyi', 'render/renderer.pyi', 'render/rst.pyi', 'METADATA.toml']},
      license="Apache-2.0 license",
      classifiers=[
          "License :: OSI Approved :: Apache Software License",
          "Typing :: Stubs Only",
      ]
)
